==> search-ui-elasticsearch-connector-1.10.2.tgz: package/lib/esm/handlers/autocomplete/index.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import resultsHandler from "./results";
import suggestionsHandler from "./suggestions";
export default function handleRequest(configuration) {
    return __awaiter(this, void 0, void 0, function* () {
        const { state, queryConfig, host, index, connectionOptions, queryFields } = configuration;
        const { apiKey } = connectionOptions || {};
        const requests = [];
        if (queryConfig.results) {
            requests.push(resultsHandler(state, queryConfig, host, index, apiKey, queryFields));
        }
        if (queryConfig.suggestions && queryConfig.suggestions.types) {
            const promises = Object.keys(queryConfig.suggestions.types).map((type) => {
                const typeConfig = queryConfig.suggestions.types[type];
                return suggestionsHandler(state, typeConfig);
            });
            requests.push(...promises);
        }
        const results = yield Promise.all(requests);
        return {
            autocompletedResults: results[0],
            autocompletedSuggestions: results[1] //todo: figure out how to handle multiple suggestions
        };
    });
}

==> search-ui-elasticsearch-connector-1.11.3.tgz: package/lib/esm/handlers/autocomplete/index.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import resultsHandler from "./results";
import suggestionsHandler from "./suggestions";
export default function handleRequest(configuration) {
    return __awaiter(this, void 0, void 0, function* () {
        const { state, queryConfig, host, index, connectionOptions } = configuration;
        const { apiKey } = connectionOptions || {};
        const requests = [];
        if (queryConfig.results) {
            requests.push(resultsHandler(state, queryConfig, host, index, apiKey));
        }
        if (queryConfig.suggestions && queryConfig.suggestions.types) {
            const promises = Object.keys(queryConfig.suggestions.types).map((type) => {
                const typeConfig = queryConfig.suggestions.types[type];
                return suggestionsHandler(state, typeConfig);
            });
            requests.push(...promises);
        }
        const results = yield Promise.all(requests);
        return {
            autocompletedResults: results[0],
            autocompletedSuggestions: results[1] //todo: figure out how to handle multiple suggestions
        };
    });
}
